@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 
 import pandas as pd
-from TrainingDataCreation import create_training_data as createData
+from training_data_creation import create_training_data as createData
 from custom_t5_model import CustomT5
 from sklearn.model_selection import train_test_split
 import os
